import abc
from abc import ABC
from datetime import datetime
from typing import Dict


class CachedService(ABC):
    def __init__(self, fetchThresholdInSeconds: int):
        self._fetchThresholdInSeconds = fetchThresholdInSeconds
        self._lastFetchTimestamp = 0
        self._data = None

    def get_data(self) -> Dict:
        if self.__is_data_obsolete():
            self._data = self._fetch_data()
            self._lastFetchTimestamp = now = datetime.now().timestamp()
        return self._data

    def __is_data_obsolete(self) -> bool:
        now = datetime.now().timestamp()
        if (now - self._lastFetchTimestamp) > self._fetchThresholdInSeconds:
            return True

        return False

    @abc.abstractmethod
    def _fetch_data(self) -> Dict:
        pass
