import unittest

from TheCodeLabs_BaseUtils.TheCodeLabs_BaseUtils.Color import Color


class ColorTest(unittest.TestCase):
    def test_to_hex(self):
        color = Color(255, 0, 0)
        self.assertEqual('#FF0000FF', color.to_hex())

    def test_to_hex_without_opacity(self):
        color = Color(255, 0, 0)
        self.assertEqual('#FF0000', color.to_hex_without_opacity())

    def test_to_rgba(self):
        color = Color(255, 0, 0)
        self.assertEqual('rgba(255, 0, 0, 1.0)', color.to_rgba())

    def test_to_rgb(self):
        color = Color(255, 0, 0)
        self.assertEqual('rgb(255, 0, 0)', color.to_rgb())

    def test_from_hex_normal(self):
        hexString = '#FF0000'
        color = Color.from_hex(hexString)
        self.assertEqual(255, color.red)
        self.assertEqual(0, color.green)
        self.assertEqual(0, color.blue)
        self.assertAlmostEqual(1.0, color.opacity, 2)

    def test_from_hex_with_opacity(self):
        hexString = '#FF000080'
        color = Color.from_hex(hexString)
        self.assertEqual(255, color.red)
        self.assertEqual(0, color.green)
        self.assertEqual(0, color.blue)
        self.assertAlmostEqual(0.5, color.opacity, 2)

    def test_from_hex_short(self):
        hexString = '#F0F'
        color = Color.from_hex(hexString)
        self.assertEqual(255, color.red)
        self.assertEqual(0, color.green)
        self.assertEqual(255, color.blue)
        self.assertAlmostEqual(1.0, color.opacity, 2)

    def test_from_invalid(self):
        hexString = '#12345'
        with self.assertRaises(ValueError):
            Color.from_hex(hexString)


if __name__ == '__main__':
    unittest.main()
